@@ -6,8 +6,27 @@
 #' particular image header. They define the relationship between the storage
 #' order of the image and real space.
 #' 
+#' Image orientation is indicated using a three-character string, with each
+#' character indicating the approximate world-space direction of the positive
+#' axes in the first, second and third dimensions, in order. Each character may
+#' be `R' for left-to-right, `L' for right-to-left, `A' for posterior-to-
+#' anterior, `P' for anterior-to-posterior, `S' for inferior-to-superior, or
+#' `I' for superior-to-inferior. The default for NIfTI is RAS, meaning that the
+#' first dimension points towards the right, the second towards the front and
+#' the third towards the top. An xform matrix is an affine transform relative
+#' to that default.
+#' 
+#' The upper-left 3x3 matrix in a 3D affine transform governs scale, rotation
+#' and skew, while the last column is a translation. (The \code{rotation}
+#' function extracts the rotation part alone.) The final row is always
+#' (0,0,0,1). Reorienting an image involves permuting and possibly reversing
+#' some of the axes, both in the data and the metadata. The sense of the
+#' translation may also need to be reversed, but this is only possible if the
+#' image dimensions are known, which isn't the case when reorienting an xform
+#' alone.
+#' 
 #' @param image,x An image, in any acceptable form (see
-#'   \code{\link{retrieveNifti}}).
+#'   \code{\link{retrieveNifti}}), or a 4x4 numeric xform matrix.
 #' @param useQuaternionFirst A single logical value. If \code{TRUE}, the
 #'   ``qform'' matrix will be used first, if it is defined; otherwise the
 #'   ``sform'' matrix will take priority.
@@ -17,10 +36,7 @@
 #' @return For \code{xform}, an affine matrix corresponding to the ``qform''
 #'   or ``sform'' information in the image header. For \code{orientation}, a
 #'   string with three characters indicating the (approximate) orientation of
-#'   the image. Each character may be `R' for left-to-right, `L' for
-#'   right-to-left, `A' for posterior-to-anterior, `P' for
-#'   anterior-to-posterior, `S' for inferior-to-superior, or `I' for
-#'   superior-to-inferior. The replacement forms return the modified object.
+#'   the image. The replacement forms return the modified object.
 #' 
 #' @note The qform and sform replacement functions are for advanced users only.
 #'   Modifying the transforms without knowing what you're doing is usually
@@ -36,6 +52,9 @@
 #' # The same as above, since the sform is unmodified
 #' xform(im)
 #' 
+#' # The identity matrix corresponds to RAS orientation
+#' orientation(diag(4))
+#' 
 #' @author Jon Clayden <code@@clayden.org>
 #' @references The NIfTI-1 standard (\url{http://www.nitrc.org/docman/view.php/26/64/nifti1.h})
 #'   is the definitive reference on ``xform'' conventions.
@@ -73,6 +92,13 @@ orientation <- function (x, useQuaternionFirst = TRUE)
     return (.Call("setOrientation", x, as.character(value), PACKAGE="RNifti"))
 }
 
+#' @rdname xform
+#' @export
+rotation <- function (x, useQuaternionFirst = TRUE)
+{
+    return (.Call("getRotation", x, isTRUE(useQuaternionFirst), PACKAGE="RNifti"))
+}
+
 #' Transform points between voxel and ``world'' coordinates
 #' 
 #' These functions are used to transform points from dimensionless pixel or
@@ -83,7 +109,8 @@ orientation <- function (x, useQuaternionFirst = TRUE)
 #' 
 #' @param points A vector giving the coordinates of a point, or a matrix with
 #'   one point per row.
-#' @param image The image in whose space the points are given.
+#' @param image The image in whose space the points are given, or a 4x4 numeric
+#'   xform matrix.
 #' @param simple A logical value: if \code{TRUE} then the transformation is
 #'   performed simply by rescaling the points according to the voxel dimensions
 #'   recorded in the \code{image}. Otherwise the full xform matrix is used.
